Modules
Structs
- Failure
- Information about server-side failure returned through RPC API
- RpcConnection
Enums
- Client
Error - Errors happening with RPC APIs received by the server, but originating from the client connection.
- Failure
Code - Symbolic representation of a failure code returned by the server
- Server
Error - Errors happening with RPC APIs on the server side and returned to the client
Traits
- Api
- RPC API pair, connecting
Requesttype withReply - Endpoint
Id - Marker traits for endpoint identifiers lists
- Failure
Code Ext - Marker trait for service-specific extended failure codes, representable as u16 integers.
- Reply
- Marker trait for LNP RPC replies
- Request
- Marker trait for LNP RPC requests